@@ -1,7 +1,7 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
-# Copyright (c) 2008-2019 pyglet contributors
+# Copyright (c) 2008-2020 pyglet contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -32,10 +32,6 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 # ----------------------------------------------------------------------------
-__docformat__ = 'restructuredtext'
-__version__ = '$Id$'
-
-from builtins import object
 
 import os
 import select
@@ -43,10 +39,10 @@ import threading
 
 from pyglet import app
 from pyglet.app.base import PlatformEventLoop
-from pyglet.compat import asbytes
+from pyglet.util import asbytes
 
 
-class XlibSelectDevice(object):
+class XlibSelectDevice:
     def fileno(self):
         """Get the file handle for ``select()`` for this device.
 
